@@ -14,7 +14,7 @@ from social_core.backends.base import BaseAuth
 
 def baseauth_init_workaround(original_init):
     def fake_init(self, strategy=None, *args, **kwargs):
-        from .utils import load_strategy
+        from .utils import load_strategy  # noqa: PLC0415
 
         original_init(self, strategy or load_strategy(), *args, **kwargs)
 
@@ -22,5 +22,5 @@ def baseauth_init_workaround(original_init):
 
 
 if not getattr(BaseAuth, "__init_patched", False):
-    BaseAuth.__init__ = baseauth_init_workaround(BaseAuth.__init__)
-    BaseAuth.__init_patched = True
+    BaseAuth.__init__ = baseauth_init_workaround(BaseAuth.__init__)  # type: ignore[method-assign]
+    BaseAuth.__init_patched = True  # type: ignore[attr-defined] # noqa: SLF001
