@@ -8,24 +8,16 @@ from social_core.utils import setting_name
 
 POSTGRES_JSONFIELD = getattr(settings, setting_name("POSTGRES_JSONFIELD"), False)
 
-if POSTGRES_JSONFIELD:
-    JSONFIELD_ENABLED = True
-else:
-    JSONFIELD_ENABLED = getattr(settings, setting_name("JSONFIELD_ENABLED"), False)
+JSONFIELD_ENABLED = True if POSTGRES_JSONFIELD else getattr(settings, setting_name("JSONFIELD_ENABLED"), False)
 
 if JSONFIELD_ENABLED:
     JSONFIELD_CUSTOM = getattr(settings, setting_name("JSONFIELD_CUSTOM"), None)
 
     if JSONFIELD_CUSTOM is not None:
-        try:
-            from django.utils.module_loading import import_string
-        except ImportError:
-            from importlib import import_module as import_string
+        from django.utils.module_loading import import_string
+
         JSONField = import_string(JSONFIELD_CUSTOM)
     else:
-        try:
-            from django.db.models import JSONField
-        except ImportError:
-            from django.contrib.postgres.fields import JSONField
+        from django.db.models import JSONField
 else:
     JSONField = models.TextField
