@@ -2,13 +2,8 @@ from django.conf import settings
 from django.db import migrations, models
 from social_core.utils import setting_name
 
-from ..fields import JSONField
-from ..storage import (
-    DjangoAssociationMixin,
-    DjangoCodeMixin,
-    DjangoNonceMixin,
-    DjangoUserMixin,
-)
+from social_django.fields import JSONField
+from social_django.storage import DjangoAssociationMixin, DjangoCodeMixin, DjangoNonceMixin, DjangoUserMixin
 
 USER_MODEL = (
     getattr(settings, setting_name("USER_MODEL"), None) or getattr(settings, "AUTH_USER_MODEL", None) or "auth.User"
